#
# spec file for package DisplayCluster
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define soname  0
%define commit  git20150515
%if 0%{?suse_version} == 1315
%bcond_without unr_pkg
%endif
Name:           DisplayCluster
Version:        0.4.0
Release:        4.16
Summary:        A collaborative software for driving large display walls
License:        BSD-2-Clause
Group:          Productivity/Multimedia/Other
Url:            https://github.com/TACC/DisplayCluster        
# Forking Project: http://bluebrain.github.io/
Source0:        https://github.com/BlueBrain/DisplayCluster/archive/0.4.0.tar.gz#/%{name}-%{version}.tar.bz2
Source1:        https://github.com/Eyescale/CMake/archive/master.tar.gz#/CMake-common_%{commit}.tar.bz2
# PATCH-FIX-UPSTREAM build.diff avvissu@yandex.ru -- Changed the paths install files and fix for 64-bit build
Patch0:         DisplayCluster-0.4.0_build.patch
# PATCH-FIX-UPSTREAM link_libraries.patch avvissu@yandex.ru -- Add link to library
Patch1:         DisplayCluster-0.4.0_link_libraries.patch
# PATCH-FIX-UPSTREAM doxygen.patch avvissu@yandex.ru --  Fix build error: need administrative privileges
Patch2:         CMake_doxygen.patch
# PATCH-FIX-UPSTREAM boost.patch avvissu@yandex.ru --  Fix build with boost >= 1.58.0
Patch3:         DisplayCluster-0.4.0_boost.patch
# PATCH-FIX-UPSTREAM boost.patch avvissu@yandex.ru --  Fix build with boost >= 1.59.0
Patch4:         DisplayCluster-0.4.0_boost-1.59.patch
BuildRequires:  ImageMagick
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(QtOpenGL)
BuildRequires:  pkgconfig(QtSvg)
BuildRequires:  pkgconfig(QtWebKit)
BuildRequires:  pkgconfig(QtXml)
BuildRequires:  pkgconfig(QtXmlPatterns)
%if 0%{?suse_version} > 1310
BuildRequires:  libjpeg8-devel
%else
BuildRequires:  libturbojpeg-devel
%endif
###########Recommends###########
BuildRequires:  FastCGI-devel
BuildRequires:  freeglut-devel
BuildRequires:  openmpi-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  python-qt4
BuildRequires:  python-qt4-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libavcodec) = 56.60.100
BuildRequires:  pkgconfig(libavformat) = 56.40.101
BuildRequires:  pkgconfig(libavutil) = 54.31.100
BuildRequires:  pkgconfig(libdts)
BuildRequires:  pkgconfig(libswscale) = 3.1.101
BuildRequires:  pkgconfig(poppler-qt4)
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(xmu)
#Error: opal_init failed
Requires:       openmpi-devel

%description
DisplayCluster is a software environment for interactively driving
large-scale tiled displays. The software allows users to interactively view
media such as high-resolution imagery and video, as well as stream content
from remote sources such as laptops / desktops or high-performance remote
visualization machines.

%package -n     libdccore%{soname}
Summary:        The core library for %{name}
License:        BSD-2-Clause
Group:          System/Libraries
Provides:       lib%{name}%{soname} = %{version}
Obsoletes:      lib%{name}%{soname} < %{version}

%description -n libdccore%{soname}
DisplayCluster is a software environment for interactively driving
large-scale tiled displays. The software allows users to interactively view
media such as high-resolution imagery and video, as well as stream content
from remote sources such as laptops / desktops or high-performance remote
visualization machines.

%package -n     libdcwebservice%{soname}
Summary:        Accepts external commands through the FastCGI protocol
License:        BSD-2-Clause
Group:          System/Libraries

%description -n libdcwebservice%{soname}
DisplayCluster is a software environment for interactively driving
large-scale tiled displays. The software allows users to interactively view
media such as high-resolution imagery and video, as well as stream content
from remote sources such as laptops / desktops or high-performance remote
visualization machines.

%package 		devel
Summary:        Development files for %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}
Requires:       boost-devel
Requires:       pkgconfig(libavcodec)
Requires:       pkgconfig(libavformat)
Requires:       pkgconfig(libavutil)
Requires:       pkgconfig(libswscale)
Requires:       FastCGI-devel

%description 	devel
A collaborative software for driving large display walls.

This package contains header files and libraries needed to develop
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
A collaborative software for driving large display walls.

This document describes the basic structure and provides information on
usage of %{name}.

%prep
%setup -q -a1
mv CMake-common* CMake/common
%patch0 -p1
%patch1 -p1
%patch3 -p1
%patch4 -p1
pushd CMake/common
%patch2 -p1
popd

# Do not compile in DATE and TIME
sed -i '/^HTML_TIMESTAMP/s/YES/NO/' $(grep -rl 'HTML_TIMESTAMP')
# Fix incorrect sRGB profile (run desktopstreamer)
for f in $(find . -type f -name \*.png); do
convert $f -strip $f
done

%build
%cmake \
	-DCMAKE_BUILD_TYPE=Release \
	-DFORCE_BUILD_DCCORE=ON \
	-DCMAKE_SKIP_RPATH:BOOL=OFF \
	-DFCGI_INCLUDE_DIR:PATH="%{_includedir}/fastcgi"

make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
%make_install -C build

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}{%{_datadir}/%{name}/doc,%{_docdir}/%{name}}

%fdupes -s %{buildroot}%{_datadir}

%check
#sed -i '/ctest/s|\(bin/ctest\)|\1 -V|' build/Makefile
#make test -C build

%post -n libdccore%{soname} -p /sbin/ldconfig

%postun -n libdccore%{soname} -p /sbin/ldconfig

%post -n libdcwebservice%{soname} -p /sbin/ldconfig

%postun -n libdcwebservice%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_docdir}/%{name}
%{_bindir}/desktopstreamer
%{_bindir}/displaycluster
%{_bindir}/localstreamer
%{_bindir}/simplestreamer
%exclude %{_docdir}/%{name}/manual.pdf
%exclude %{_docdir}/%{name}/API

%files -n libdccore%{soname}
%defattr(-,root,root)
%{_libdir}/libdccore.so.*
%{_libdir}/libdcstream.so.*

%files -n libdcwebservice%{soname}
%defattr(-,root,root)
%{_libdir}/libdcwebservice.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/dc
%{_libdir}/libdccore.so
%{_libdir}/libdcstream.so
%{_libdir}/libdcwebservice.so
%{_libdir}/pkgconfig/%{name}.pc
%{_bindir}/startdisplaycluster
%{_datadir}/%{name}

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/manual.pdf
%{_docdir}/%{name}/API

%changelog
* Fri Dec  4 2015 avvissu@yandex.ru
- Fix build with boost >= 1.59.0:
  * add DisplayCluster-0.4.0_boost-1.59.patch
* Thu May 21 2015 avvissu@yandex.ru
- Fix build with boost >= 1.58.0 (DisplayCluster-0.4.0_boost.patch)
* Mon May 18 2015 avvissu@yandex.ru
- Add recommended packages for *-devel
* Fri May 15 2015 avvissu@yandex.ru
- Update to 0.4.0:
  * the core library renamed on libdccore
  * add dcWebservice: accepts external commands through the FastCGI
    protocol
  * add doc: Doxygen and other documentation
- Use fork instead of the original project
- Add source package CMake-common (Common CMake modules)
- Drop old patches:
  * build.diff
  * path_to_mpirun.diff
  * DisplayCluster-git.20130524-ffmpeg-2.5.patch
- Add new patches:
  * fix build on 64-bit (DisplayCluster-0.4.0_build.patch)
  * add link to library (DisplayCluster-0.4.0_link_libraries.patch)
  * CMake_doxygen.patch
- Add recommended packages to build with optional packages
- Use pkgconfig in package names
- Fix incorrect sRGB profile
- Use %%%%cmake macro instead of cmake
- Spec file cleanup
* Tue Mar  3 2015 avvissu@yandex.ru
- Fix build with current ffmpeg:
  * add DisplayCluster-git.20130524-ffmpeg-2.5.patch
- Moving the examples directory in developing package
* Wed Mar 12 2014 avvissu@yandex.ru
- [Fixed] Error, could not find mpirun executable in PATH
  * add  path_to_mpirun.diff
* Tue Mar 11 2014 avvissu@yandex.ru
- [Fixed] opal_init failed: Returned value Error (-1) instead of
  ORTE_SUCCESS (add Requires: openmpi-devel)
* Mon Mar 10 2014 avvissu@yandex.ru
- Initial release
